@@ -63,7 +63,7 @@ def post_model(environment, organization_id, model_config):
     )
 
     require_ok_response(response)
-    return json.loads(response.text)["model_id"]
+    return response.json()["id"]
 
 
 def delete_model(environment, organization_id, model_id):
