@@ -5,7 +5,7 @@ import uuid
 from lib.autumn8 import api
 
 
-def upload_model(environment, organization_id, model_config, model_file):
+def upload_model(environment, organization_id, model_config, model_file, input_file):
     autodl_host = environment.value["host"]
     if type(model_file) == io.BytesIO:
         model_file.seek(0)
@@ -18,6 +18,12 @@ def upload_model(environment, organization_id, model_config, model_file):
     print("Uploading the model files...")
     api.post_model_file(environment, model_file, s3_file_url)
     model_config["s3_file_url"] = s3_file_url
+    
+    if input_file != None and len(input_file) > 0:
+        s3_input_file_url = f"autodl-staging/inputs/{uuid.uuid4()}-{input_file}"
+        print("Uploading the input files...")
+        api.post_model_file(environment, input_file, s3_input_file_url)
+        model_config["s3_input_file_url"] = s3_input_file_url
 
     print("Creating the model entry in AutoDL...")
     model_id = api.post_model(environment, organization_id, model_config)
