@@ -2,6 +2,7 @@ import json
 import random
 import uuid
 from configparser import NoOptionError, NoSectionError
+import os
 
 import click
 import jsonschema
@@ -102,7 +103,27 @@ def validate_input_dims_json(jsonString):
     ):
         return False
     return True
+    
+INPUT_FILE_JSONSCHEMA = {
+    "type": "array",
+    "minItems": 1,
+}
+    
+def validate_input_file(path):
+    if not os.path.exists(path):
+        return False
 
+    try:
+        with open(path, 'r') as f:
+            jsonData = json.load(f)
+            
+        validate(instance=jsonData, schema=INPUT_FILE_JSONSCHEMA)
+    except (
+        jsonschema.exceptions.ValidationError,
+        json.decoder.JSONDecodeError,
+    ):
+        return False
+    return True
 
 def normalize_input_dims_for_api(input_dims):
     if not input_dims:
@@ -119,6 +140,7 @@ def prompt_for_missing_model_info(
     model_name,
     quantization,
     input_dims,
+    input_file,
     inferred_model_name,
     inferred_quantization,
     inferred_input_dims,
@@ -137,13 +159,32 @@ def prompt_for_missing_model_info(
             use_shortcuts=True,
             default=inferred_quantization,
         ).unsafe_ask()
-    if input_dims is None:
+
+    input_methods = ["Upload input file", "Specify input shape", "Let us try to infer input shape"]
+    input_method = input_methods[2]
+
+    if input_dims is None and input_file is None:
+        input_method = questionary.select(
+            "Specify input",
+            choices=input_methods,
+            use_shortcuts=True,
+            default=input_methods[0],
+        ).unsafe_ask()
+    
+    if input_method == input_methods[1] and input_dims is None:
         input_dims = questionary.text(
             "Specify input dimensions for every model input as an array of JSON arrays "
             + '(ie. "[[3, 224, 224]]"), or leave blank to let us try to infer the input sizes")',
             validate=lambda inputs: validate_input_dims_json(inputs),
             default=str(inferred_input_dims) if inferred_input_dims else "",
         ).unsafe_ask()
+        
+    if input_method == input_methods[0] and input_dims is None:
+        input_file = questionary.text(
+            "Write input file path",
+            validate=validate_input_file,
+            default="",
+        ).unsafe_ask()
 
     input_dims = normalize_input_dims_for_api(input_dims)
 
@@ -151,6 +192,7 @@ def prompt_for_missing_model_info(
         model_name,
         quantization,
         input_dims,
+        input_file
     )
 
 
@@ -179,12 +221,15 @@ def prompt_for_missing_model_info(
     help="Quantization for the model.",
 )
 @click.option(
-    "-i",
     "--input_dims",
-    "--inputs",
     type=str,
     help="The model input dimensions, specified as a JSON array",
 )
+@click.option(
+    "--input_file",
+    type=str,
+    help="The model input filepath",
+)
 @click.option(
     "-y",
     "--yes",
@@ -212,6 +257,7 @@ def submit_model(
     auto_confirm,
     quantization,
     input_dims,
+    input_file,
     group_id,
     **kwargs,
 ):
@@ -231,10 +277,11 @@ def submit_model(
         inferred_input_dims,
     ) = analyze_model_file(model_file_path, model_script_args)
 
-    (model_name, quantization, input_dims,) = prompt_for_missing_model_info(
+    (model_name, quantization, input_dims, input_file) = prompt_for_missing_model_info(
         model_name,
         quantization,
         input_dims,
+        input_file,
         inferred_model_name,
         inferred_quantization,
         inferred_input_dims,
@@ -260,6 +307,6 @@ def submit_model(
         )
 
     model_link = autodl.upload_model(
-        environment, organization_id, model_config, model_file
+        environment, organization_id, model_config, model_file, input_file
     )
     print(f"\nDone!\nSee {model_link}")
